@@ -3,5 +3,5 @@
 """
 from .api import ExbetAPI
 
-__version__ = "2.0.0"
-__all__ = ["api", "exceptions"]
+__version__ = "2.1.0"
+__all__ = ["api", "exceptions", "cli"]
